==> blesta-5.10.2.zip: blesta/language/ro_ro/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Toggle Navigation';
$lang['AppController.sreader.dropdown'] = 'Toggle Dropdown';
$lang['AppController.graphs.label.total'] = 'Total';
$lang['AppController.graphs.control_label.grouped'] = 'Grupate';
$lang['AppController.graphs.control_label.expanded'] = 'Extinse';
$lang['AppController.graphs.control_label.stream'] = 'Flux';
$lang['AppController.graphs.control_label.stacked'] = 'Stivuite';
$lang['AppController.dates.monthabbr_dec'] = 'Dec';
$lang['AppController.dates.monthabbr_nov'] = 'Noiembrie';
$lang['AppController.dates.monthabbr_oct'] = 'Octombrie';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Iulie';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_apr'] = 'Apr';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_feb'] = 'Feb';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Decembrie';
$lang['AppController.dates.month_nov'] = 'Noiembrie';
$lang['AppController.dates.month_oct'] = 'Octombrie';
$lang['AppController.dates.month_sep'] = 'Septembrie';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_jul'] = 'Iulie';
$lang['AppController.dates.month_jun'] = 'Iunie';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_apr'] = 'Aprilie';
$lang['AppController.dates.month_mar'] = 'Martie';
$lang['AppController.dates.month_feb'] = 'Februarie';
$lang['AppController.dates.month_jan'] = 'Ianuarie';
$lang['AppController.dates.dayabbr_sat'] = 'Sâmbătă';
$lang['AppController.dates.dayabbr_fri'] = 'vineri';
$lang['AppController.dates.dayabbr_thur'] = 'Joi';
$lang['AppController.dates.dayabbr_wed'] = 'Miercuri';
$lang['AppController.dates.dayabbr_tue'] = 'Marți';
$lang['AppController.dates.dayabbr_mon'] = 'Luni';
$lang['AppController.dates.dayabbr_sun'] = 'Sun';
$lang['AppController.dates.day_sat'] = 'Sâmbătă';
$lang['AppController.dates.day_fri'] = 'Vineri';
$lang['AppController.dates.day_thu'] = 'Joi';
$lang['AppController.dates.day_wed'] = 'Miercuri';
$lang['AppController.dates.day_tue'] = 'Marți';
$lang['AppController.dates.day_mon'] = 'Luni';
$lang['AppController.dates.day_sun'] = 'Duminică';
$lang['AppController.client_structure.text_managers'] = 'Manageri';
$lang['AppController.client_structure.text_contacts'] = 'Contacte';
$lang['AppController.client_structure.text_accounts'] = 'Conturi de plată';
$lang['AppController.client_structure.text_emails'] = 'Istoric e-mail';
$lang['AppController.client_structure.text_update_account'] = 'Gestionați contul';
$lang['AppController.client_structure.text_login'] = 'Autentificare';
$lang['AppController.client_structure.text_logout'] = 'Deconectați-vă';
$lang['AppController.client_structure.text_return_to_portal'] = 'Întoarcerea la Portal';
$lang['AppController.client_structure.default_title'] = 'Contul meu';
$lang['AppController.client_structure.staff_as_client_note'] = 'Întoarceți-vă la Portalul personalului';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Modul de întreținere este activat în prezent, iar clienții nu se pot conecta. Faceți clic aici pentru a schimba.';
$lang['AppController.structure.text_logout'] = 'Deconectați-vă';
$lang['AppController.structure.text_settings'] = 'Setări';
$lang['AppController.structure.text_myinfo'] = 'Informațiile mele';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Treceți înapoi în contul meu';
$lang['AppController.banners.client_manager'] = 'În prezent, gestionați un cont care v-a invitat să îl gestionați.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Vă rugăm să confirmați';
$lang['AppController.modal.text_close'] = 'Închideți';
$lang['AppController.select.please'] = '-- Vă rugăm să selectați --';
$lang['AppController.!success.license_key_updated'] = 'Cheia dvs. de licență a fost actualizată cu succes. Vă rugăm să vă conectați.';
$lang['AppController.!success.license_updated'] = 'Licența dumneavoastră a fost revalidată cu succes. Vă rugăm să vă conectați.';
$lang['AppController.!error.invalid_csrf'] = 'Simbolul formularului nu este valid.';
$lang['AppController.!error.unauthorized_access'] = 'Nu sunteți autorizat să accesați această resursă';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';

==> blesta-5.11.4.zip: blesta/language/ro_ro/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.sreader.navigation'] = 'Toggle Navigation';
$lang['AppController.sreader.dropdown'] = 'Toggle Dropdown';
$lang['AppController.graphs.label.total'] = 'Total';
$lang['AppController.graphs.control_label.grouped'] = 'Grupate';
$lang['AppController.graphs.control_label.expanded'] = 'Extinse';
$lang['AppController.graphs.control_label.stream'] = 'Flux';
$lang['AppController.graphs.control_label.stacked'] = 'Stivuite';
$lang['AppController.dates.monthabbr_dec'] = 'Dec';
$lang['AppController.dates.monthabbr_nov'] = 'Noiembrie';
$lang['AppController.dates.monthabbr_oct'] = 'Octombrie';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_aug'] = 'Aug';
$lang['AppController.dates.monthabbr_jul'] = 'Iulie';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_apr'] = 'Apr';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_feb'] = 'Feb';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.month_dec'] = 'Decembrie';
$lang['AppController.dates.month_nov'] = 'Noiembrie';
$lang['AppController.dates.month_oct'] = 'Octombrie';
$lang['AppController.dates.month_sep'] = 'Septembrie';
$lang['AppController.dates.month_aug'] = 'August';
$lang['AppController.dates.month_jul'] = 'Iulie';
$lang['AppController.dates.month_jun'] = 'Iunie';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_apr'] = 'Aprilie';
$lang['AppController.dates.month_mar'] = 'Martie';
$lang['AppController.dates.month_feb'] = 'Februarie';
$lang['AppController.dates.month_jan'] = 'Ianuarie';
$lang['AppController.dates.dayabbr_sat'] = 'Sâmbătă';
$lang['AppController.dates.dayabbr_fri'] = 'vineri';
$lang['AppController.dates.dayabbr_thur'] = 'Joi';
$lang['AppController.dates.dayabbr_wed'] = 'Miercuri';
$lang['AppController.dates.dayabbr_tue'] = 'Marți';
$lang['AppController.dates.dayabbr_mon'] = 'Luni';
$lang['AppController.dates.dayabbr_sun'] = 'Sun';
$lang['AppController.dates.day_sat'] = 'Sâmbătă';
$lang['AppController.dates.day_fri'] = 'Vineri';
$lang['AppController.dates.day_thu'] = 'Joi';
$lang['AppController.dates.day_wed'] = 'Miercuri';
$lang['AppController.dates.day_tue'] = 'Marți';
$lang['AppController.dates.day_mon'] = 'Luni';
$lang['AppController.dates.day_sun'] = 'Duminică';
$lang['AppController.client_structure.text_managers'] = 'Manageri';
$lang['AppController.client_structure.text_contacts'] = 'Contacte';
$lang['AppController.client_structure.text_accounts'] = 'Conturi de plată';
$lang['AppController.client_structure.text_emails'] = 'Istoric e-mail';
$lang['AppController.client_structure.text_update_account'] = 'Gestionați contul';
$lang['AppController.client_structure.text_login'] = 'Autentificare';
$lang['AppController.client_structure.text_logout'] = 'Deconectați-vă';
$lang['AppController.client_structure.text_return_to_portal'] = 'Întoarcerea la Portal';
$lang['AppController.client_structure.default_title'] = 'Contul meu';
$lang['AppController.client_structure.staff_as_client_note'] = 'Întoarceți-vă la Portalul personalului';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.structure.text_maintenance'] = 'Modul de întreținere este activat în prezent, iar clienții nu se pot conecta. Faceți clic aici pentru a schimba.';
$lang['AppController.structure.text_logout'] = 'Deconectați-vă';
$lang['AppController.structure.text_settings'] = 'Setări';
$lang['AppController.structure.text_myinfo'] = 'Informațiile mele';
$lang['AppController.message.close'] = '×';
$lang['AppController.banners.text_switch_back'] = 'Treceți înapoi în contul meu';
$lang['AppController.banners.client_manager'] = 'În prezent, gestionați un cont care v-a invitat să îl gestionați.';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.modal.text_confirm'] = 'Vă rugăm să confirmați';
$lang['AppController.modal.text_close'] = 'Închideți';
$lang['AppController.select.please'] = '-- Vă rugăm să selectați --';
$lang['AppController.!success.license_key_updated'] = 'Cheia dvs. de licență a fost actualizată cu succes. Vă rugăm să vă conectați.';
$lang['AppController.!success.license_updated'] = 'Licența dumneavoastră a fost revalidată cu succes. Vă rugăm să vă conectați.';
$lang['AppController.!error.invalid_csrf'] = 'Simbolul formularului nu este valid.';
$lang['AppController.!error.unauthorized_access'] = 'Nu sunteți autorizat să accesați această resursă';
$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.dropzone.text'] = 'Aruncați fișierele aici pentru a le încărca sau faceți clic pentru a selecta fișiere';
$lang['AppController.!error.client_unauthorized_access'] = 'Nu aveți permisiunea de a accesa această resursă, vă rugăm să contactați titularul principal al contului pentru a solicita accesul';
